ArticlesStoreInstantiater class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- noPersistence → ArticlesStore
-
no setter
Static Methods
-
instArticlesStoreSembastTest(
DbArticles dbArticles, DbOfflineQueue dbQueue) → ArticlesStore -
noPersistenceWithData(
{required List< CalibreWeebi< articlesInitData, List<ArticleRawAbstract> >ArticlePhoto> ? photos}) → ArticlesStore -
testCloudOffline(
{required DbOfflineQueue dbOffline}) → ArticlesStore